==> atf-0.6.tar.gz: atf-0.6/atf-c++/signals.hpp <==
//
// Automated Testing Framework (atf)
//
// Copyright (c) 2007, 2008 The NetBSD Foundation, Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions
// are met:
// 1. Redistributions of source code must retain the above copyright
//    notice, this list of conditions and the following disclaimer.
// 2. Redistributions in binary form must reproduce the above copyright
//    notice, this list of conditions and the following disclaimer in the
//    documentation and/or other materials provided with the distribution.
//
// THIS SOFTWARE IS PROVIDED BY THE NETBSD FOUNDATION, INC. AND
// CONTRIBUTORS ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES,
// INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
// MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
// IN NO EVENT SHALL THE FOUNDATION OR CONTRIBUTORS BE LIABLE FOR ANY
// DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
// GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
// INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
// IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
// OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN
// IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//

#if !defined(_ATF_CXX_SIGNALS_HPP_)
#define _ATF_CXX_SIGNALS_HPP_

extern "C" {
#include <signal.h>
}

#include <map>

extern "C" {
#include "atf-c/signals.h"
}

namespace atf {
namespace signals {

extern const int last_signo;
typedef atf_signal_handler_t handler;

// ------------------------------------------------------------------------
// The "signal_holder" class.
// ------------------------------------------------------------------------

//
// A RAII model to hold a signal while the object is alive.
//
class signal_holder {
    atf_signal_holder_t m_sh;

public:
    signal_holder(int);
    ~signal_holder(void);

    void process(void);
};

// ------------------------------------------------------------------------
// The "signal_programmer" class.
// ------------------------------------------------------------------------

//
// A RAII model to program a signal while the object is alive.
//
class signal_programmer {
    atf_signal_programmer_t m_sp;

public:
    signal_programmer(int, handler);
    ~signal_programmer(void);
};

} // namespace signals
} // namespace atf

#endif // !defined(_ATF_CXX_SIGNALS_HPP_)

==> atf-0.9.tar.gz: atf-0.9/atf-c++/signals.hpp <==
//
// Automated Testing Framework (atf)
//
// Copyright (c) 2007, 2008, 2010 The NetBSD Foundation, Inc.
// All rights reserved.
//
// Redistribution and use in source and binary forms, with or without
// modification, are permitted provided that the following conditions
// are met:
// 1. Redistributions of source code must retain the above copyright
//    notice, this list of conditions and the following disclaimer.
// 2. Redistributions in binary form must reproduce the above copyright
//    notice, this list of conditions and the following disclaimer in the
//    documentation and/or other materials provided with the distribution.
//
// THIS SOFTWARE IS PROVIDED BY THE NETBSD FOUNDATION, INC. AND
// CONTRIBUTORS ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES,
// INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
// MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
// IN NO EVENT SHALL THE FOUNDATION OR CONTRIBUTORS BE LIABLE FOR ANY
// DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
// DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
// GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
// INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
// IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
// OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN
// IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
//

#if !defined(_ATF_CXX_SIGNALS_HPP_)
#define _ATF_CXX_SIGNALS_HPP_

extern "C" {
#include <signal.h>
}

namespace atf {
namespace signals {

extern const int last_signo;
typedef void (*handler)(const int);

class signal_programmer;

// ------------------------------------------------------------------------
// The "signal_holder" class.
// ------------------------------------------------------------------------

//
// A RAII model to hold a signal while the object is alive.
//
class signal_holder {
    const int m_signo;
    signal_programmer* m_sp;

public:
    signal_holder(const int);
    ~signal_holder(void);

    void process(void);
};

// ------------------------------------------------------------------------
// The "signal_programmer" class.
// ------------------------------------------------------------------------

//
// A RAII model to program a signal while the object is alive.
//
class signal_programmer {
    const int m_signo;
    const handler m_handler;
    struct sigaction m_oldsa;

public:
    signal_programmer(const int, const handler);
    ~signal_programmer(void);
};

// ------------------------------------------------------------------------
// Free functions.
// ------------------------------------------------------------------------

void reset(const int);

} // namespace signals
} // namespace atf

#endif // !defined(_ATF_CXX_SIGNALS_HPP_)
